Thanks for considering submitting a pull request, we really appreciate that!

Before doing so, here are a few guidelines:

* You agree to license your contributions under the
  [license](https://github.com/Kinto/kinto/blob/main/LICENSE).
* Use pull-requests early so it's open for discussion, even if your
  contribution isn't ready yet.
* All pull requests should include tests, as they help us avoid regressions in
  our code.
* A pull-request adding functionality should also update the documentation
  accordingly.
* [CI integration tests](https://github.com/Kinto/kinto/actions) should be green.
* If you're interested, you can also check the [contributing
  documentation](https://kinto.readthedocs.io/en/latest/community.html#how-to-contribute)
  guide which goes into more details.
